==> gi-assets-algorithm-2.3.16.tgz: package/es/InfoDetection/DegreeScatter.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { Scatter } from '@antv/g2plot';
import { Card, Select } from 'antd';
import React from 'react';
import $i18n from '../i18n';
var options = [{
  label: $i18n.get({
    id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.TotalDegree',
    dm: '总度数'
  }),
  value: 'totalDegree'
}, {
  label: $i18n.get({
    id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.Outdegree',
    dm: '出度'
  }),
  value: 'outDegree'
}, {
  label: $i18n.get({
    id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.Penetration',
    dm: '入度'
  }),
  value: 'inDegree'
}];
var DegreeScatter = function DegreeScatter(props) {
  var degree = props.degree;
  var _React$useState = React.useState('totalDegree'),
    _React$useState2 = _slicedToArray(_React$useState, 2),
    current = _React$useState2[0],
    setCurrent = _React$useState2[1];
  // React.useEffect(() => {
  //   G2.registerInteraction('other-visible', {
  //       showEnable: [
  //         { trigger: 'plot:mouseenter', action: 'cursor:crosshair' },
  //         { trigger: 'mask:mouseenter', action: 'cursor:move' },
  //         { trigger: 'plot:mouseleave', action: 'cursor:default' },
  //         { trigger: 'mask:mouseleave', action: 'cursor:crosshair' },
  //       ],
  //       start: [
  //         {
  //           trigger: 'plot:mousedown', isEnable(context) {
  //             return !context.isInShape('mask');
  //           }, action: ['rect-mask:start', 'rect-mask:show']
  //         },
  //         { trigger: 'mask:dragstart', action: 'rect-mask:moveStart' }
  //       ],
  //       processing: [
  //         { trigger: 'plot:mousemove', action: 'rect-mask:resize' },
  //         {
  //           trigger: 'mask:drag', isEnable(context) {
  //             return context.isInPlot();
  //           }, action: 'rect-mask:move'
  //         },
  //         { trigger: 'mask:change', action: 'element-sibling-filter:filter' }
  //       ],
  //       end: [
  //         { trigger: 'plot:mouseup', action: 'rect-mask:end' },
  //         { trigger: 'mask:dragend', action: 'rect-mask:moveEnd' }
  //       ],
  //       rollback: [
  //         { trigger: 'dblclick', action: ['rect-mask:hide', 'element-sibling-filter:reset'] }
  //       ]
  //     });
  // }, [])
  React.useEffect(function () {
    var data = _toConsumableArray(degree[current].entries()).map(function (item) {
      var _item = _slicedToArray(item, 2),
        value = _item[0],
        count = _item[1];
      return {
        value: value,
        count: count
      };
    });
    var scatterPlot = new Scatter('gi-info-detection-degree-scatter', {
      //data: chartData,
      data: data,
      height: 300,
      xField: 'value',
      yField: 'count',
      interactions: [{
        type: 'other-visible'
      }],
      size: 5,
      pointStyle: {
        fill: '#5B8FF9'
      },
      xAxis: {
        title: {
          text: $i18n.get({
            id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.Degree',
            dm: '度数'
          })
        }
      },
      yAxis: {
        title: {
          text: $i18n.get({
            id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.Quantity',
            dm: '数量'
          })
        }
      }
    });
    scatterPlot.render();
    return function () {
      scatterPlot.destroy();
    };
  }, [degree, current]);
  var extra = /*#__PURE__*/React.createElement(Select, {
    options: options,
    value: current,
    onChange: function onChange(val) {
      return setCurrent(val);
    }
  });
  return /*#__PURE__*/React.createElement(Card, {
    title: $i18n.get({
      id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.DegreeDistribution',
      dm: '度数分布'
    }),
    extra: extra
  }, /*#__PURE__*/React.createElement("div", {
    id: "gi-info-detection-degree-scatter"
  }));
};
export default DegreeScatter;

==> gi-assets-algorithm-2.3.19.tgz: package/es/InfoDetection/DegreeScatter.js <==
function _toConsumableArray(r) { return _arrayWithoutHoles(r) || _iterableToArray(r) || _unsupportedIterableToArray(r) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(r) { if ("undefined" != typeof Symbol && null != r[Symbol.iterator] || null != r["@@iterator"]) return Array.from(r); }
function _arrayWithoutHoles(r) { if (Array.isArray(r)) return _arrayLikeToArray(r); }
function _slicedToArray(r, e) { return _arrayWithHoles(r) || _iterableToArrayLimit(r, e) || _unsupportedIterableToArray(r, e) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(r, a) { if (r) { if ("string" == typeof r) return _arrayLikeToArray(r, a); var t = {}.toString.call(r).slice(8, -1); return "Object" === t && r.constructor && (t = r.constructor.name), "Map" === t || "Set" === t ? Array.from(r) : "Arguments" === t || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(t) ? _arrayLikeToArray(r, a) : void 0; } }
function _arrayLikeToArray(r, a) { (null == a || a > r.length) && (a = r.length); for (var e = 0, n = Array(a); e < a; e++) n[e] = r[e]; return n; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(r) { if (Array.isArray(r)) return r; }
import { Scatter } from '@antv/g2plot';
import { Card, Select } from 'antd';
import React from 'react';
import $i18n from '../i18n';
var options = [{
  label: $i18n.get({
    id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.TotalDegree',
    dm: '总度数'
  }),
  value: 'totalDegree'
}, {
  label: $i18n.get({
    id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.Outdegree',
    dm: '出度'
  }),
  value: 'outDegree'
}, {
  label: $i18n.get({
    id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.Penetration',
    dm: '入度'
  }),
  value: 'inDegree'
}];
var DegreeScatter = function DegreeScatter(props) {
  var degree = props.degree;
  var _React$useState = React.useState('totalDegree'),
    _React$useState2 = _slicedToArray(_React$useState, 2),
    current = _React$useState2[0],
    setCurrent = _React$useState2[1];
  // React.useEffect(() => {
  //   G2.registerInteraction('other-visible', {
  //       showEnable: [
  //         { trigger: 'plot:mouseenter', action: 'cursor:crosshair' },
  //         { trigger: 'mask:mouseenter', action: 'cursor:move' },
  //         { trigger: 'plot:mouseleave', action: 'cursor:default' },
  //         { trigger: 'mask:mouseleave', action: 'cursor:crosshair' },
  //       ],
  //       start: [
  //         {
  //           trigger: 'plot:mousedown', isEnable(context) {
  //             return !context.isInShape('mask');
  //           }, action: ['rect-mask:start', 'rect-mask:show']
  //         },
  //         { trigger: 'mask:dragstart', action: 'rect-mask:moveStart' }
  //       ],
  //       processing: [
  //         { trigger: 'plot:mousemove', action: 'rect-mask:resize' },
  //         {
  //           trigger: 'mask:drag', isEnable(context) {
  //             return context.isInPlot();
  //           }, action: 'rect-mask:move'
  //         },
  //         { trigger: 'mask:change', action: 'element-sibling-filter:filter' }
  //       ],
  //       end: [
  //         { trigger: 'plot:mouseup', action: 'rect-mask:end' },
  //         { trigger: 'mask:dragend', action: 'rect-mask:moveEnd' }
  //       ],
  //       rollback: [
  //         { trigger: 'dblclick', action: ['rect-mask:hide', 'element-sibling-filter:reset'] }
  //       ]
  //     });
  // }, [])
  React.useEffect(function () {
    var data = _toConsumableArray(degree[current].entries()).map(function (item) {
      var _item = _slicedToArray(item, 2),
        value = _item[0],
        count = _item[1];
      return {
        value: value,
        count: count
      };
    });
    var scatterPlot = new Scatter('gi-info-detection-degree-scatter', {
      //data: chartData,
      data: data,
      height: 300,
      xField: 'value',
      yField: 'count',
      interactions: [{
        type: 'other-visible'
      }],
      size: 5,
      pointStyle: {
        fill: '#5B8FF9'
      },
      xAxis: {
        title: {
          text: $i18n.get({
            id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.Degree',
            dm: '度数'
          })
        }
      },
      yAxis: {
        title: {
          text: $i18n.get({
            id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.Quantity',
            dm: '数量'
          })
        }
      }
    });
    scatterPlot.render();
    return function () {
      scatterPlot.destroy();
    };
  }, [degree, current]);
  var extra = /*#__PURE__*/React.createElement(Select, {
    options: options,
    value: current,
    onChange: function onChange(val) {
      return setCurrent(val);
    }
  });
  return /*#__PURE__*/React.createElement(Card, {
    title: $i18n.get({
      id: 'gi-assets-algorithm.src.InfoDetection.DegreeScatter.DegreeDistribution',
      dm: '度数分布'
    }),
    extra: extra
  }, /*#__PURE__*/React.createElement("div", {
    id: "gi-info-detection-degree-scatter"
  }));
};
export default DegreeScatter;
